@@ -19,7 +19,77 @@ Usage: umls-similarity.pl [OPTIONS] [CUI1|TERM1] [CUI2|TERM2]
 
 The input are two terms or two CUIs associated to concepts in the UMLS. 
 
-=head2 Optional Arguments:
+=head2 General Options:
+
+=head3 --config FILE
+
+This is the configuration file. The format of the configuration 
+file is as follows:
+
+SAB :: <include|exclude> <source1, source2, ... sourceN>
+
+REL :: <include|exclude> <relation1, relation2, ... relationN>
+
+For example, if we wanted to use the MSH vocabulary with only 
+the RB/RN relations, the configuration file would be:
+
+SAB :: include MSH
+REL :: include RB, RN
+
+or 
+
+SAB :: include MSH
+REL :: exclude PAR, CHD
+
+If you go to the configuration file directory, there will 
+be example configuration files for the different runs that 
+you have performed.
+
+=head3 --realtime
+
+This option will not create a database of the path information
+for all of concepts in the specified set of sources and relations 
+in the config file but obtain the information for just the 
+input concept
+
+=head3 --forcerun
+
+This option will bypass any command prompts such as asking 
+if you would like to continue with the index creation. 
+
+=head3 --measure MEASURE
+
+Use the MEASURE module to calculate the semantic similarity. The 
+available measure are: 
+    1. Leacock and Chodorow (1998) refered to as lch
+    2. Wu and Palmer (1994) refered to as  wup
+    3. The basic path measure refered to as path
+    4. Rada, et. al. (1989) refered to as cdist
+    5. Nguyan and Al-Mubaid (2006) refered to as nam
+    6. Resnik (1996) refered to as res
+    7. Lin (1988) refered to as lin
+    8. Jiang and Conrath (1997) refered to as jcn
+    9. The vector measure refered to as vector
+
+=head3 --precision N
+
+Displays values upto N places of decimal.
+
+=head3 --allsenses
+
+This option prints out all the possible CUIs pairs and their semantic 
+similarity score if one of the inputs is a term that maps to more than 
+one CUI. Right now we just return the CUIs that are the most similar.
+
+=head3 --help
+
+Displays the quick summary of program options.
+
+=head3 --version
+
+Displays the version information.
+
+=head2 Input Options:
 
 =head3 --infile FILE
 
@@ -45,16 +115,6 @@ Unless the --matrix option is chosen then it is just a list of CUIS:
     cui3 
     ...
 
-=head3 --propagationfile FILE
-
-FILE containing the propagation counts of the CUIs. This file must be 
-in the following format:
-
-    freq|CUI|string
-
-where freq   = the frequency of the concept
-      CUI    = the concept's UMLS CUI
-      string = the term associated with the CUI 
 
 =head3 --matrix
 
@@ -62,6 +122,25 @@ This option returns a matrix of similarity scores given a file
 containing a list of CUIs. The file is passed using the --infile
 option
 
+=head2 Debug Options: 
+
+=head3 --debug
+
+Sets the UMLS-Interface debug flag on for testing
+
+=head3 --info
+
+Displays information about the concept if it doesn't
+exist in the source.
+
+=head3 --verbose
+
+This option will print out the table information to the 
+config file that you specified.
+
+
+=head2 Database Options:
+
 =head3 --username STRING
 
 Username is required to access the umls database on MySql
@@ -78,69 +157,85 @@ Hostname where mysql is located. DEFAULT: localhost
 
 Database contain UMLS DEFAULT: umls
 
-=head3 --measure MEASURE
+=head2 IC Measure Options:
 
-Use the MEASURE module to calculate the semantic similarity. The 
-available measure are: 
-    1. Leacock and Chodorow (1998) refered to as lch
-    2. Wu and Palmer (1994) refered to as  wup
-    3. The basic path measure refered to as path
-    4. Rada, et. al. (1989) refered to as cdist
-    5. Nguyan and Al-Mubaid (2006) refered to as nam
+=head3 --icpropagation FILE
 
-=head3 --precision N
+FILE containing the propagation counts of the CUIs. This file must be 
+in the following format:
 
-Displays values upto N places of decimal.
+    CUI<>ic
 
-=head3 --info
+where ci     = the information content of the CUI
+      CUI    = the concept's UMLS CUI
 
-Displays information about the concept if it doesn't
-exist in the source.
+See example in samples/ directory called icpropagation. 
+
+=head3 --icfrequency FILE
+
+FILE containing frequency counts of CUIs. This file must be in the following 
+format: 
+
+    CUI<>freq
+
+where freq   = the frequency of the concept
+      CUI    = the concept's UMLS CUI
+
+See example in samples/ directory called icfrequency. 
+
+
+
+=head2 Vector Measure Options:
+
+=head3 --vectormatrix FILE
+
+This is the matrix file that contains the vector information to 
+use with the vector measure. This is required if you specify vector 
+with the --measure option. 
+
+This file is generated by the vector-input.pl program. An example 
+of this file can be found in the samples/ directory and is called 
+matrix.
+
+=head3 --vectorindex FILE
+
+This is the index file that contains the vector information to 
+use with the vector measure. This is required if you specify vector 
+with the --measure option.
+
+This file is generated by the vector-input.pl program. An example 
+of this file can be found in the samples/ directory and is called 
+index.
 
 =head3 --debugfile FILE
 
 This prints the vector information to file, FILE, for debugging 
 purposes.
 
-=head3 --matrixfile FILE
+=head3 --dictfile FILE
 
-This is the matrix file that contains the vector information to 
-use with the vector measure. This is required if you specify vector 
-with the --measure option.
+This is a dictionary file for the vector measure. It contains 
+the 'definitions' of a concept which would be used rather than 
+the definitions from the UMLS
 
-=head3 --indexfile FILE
+The format of this file is:
 
-This is the index file that contains the vector information to 
-use with the vector measure. This is required if you specify vector 
-with the --measure option.
+CUI <definition>
+CUI <definition>
 
-=head3 --allsenses
+Keep in mind, when using this file, if one of the CUIs that you 
+are obtaining the similarity for does not exist in the file the 
+vector will be empty which will lead to strange similarity scores.
 
-This option prints out all the possible CUIs pairs and their semantic 
-similarity score if one of the inputs is a term that maps to more than 
-one CUI. Right now we just return the CUIs that are the most similar.
+An example of this file can be found in the samples/ directory and 
+is called dictfile.
 
-=head3 --forcerun
 
-This option will bypass any command prompts such as asking 
-if you would like to continue with the index creation. 
+=head3 --defraw
 
-=head3 --debug
-
-Sets the UMLS-Interface debug flag on for testing
-
-=head3 --verbose
-
-This option will print out the table information to the 
-config file that you specified.
-
-=head3 --help
-
-Displays the quick summary of program options.
-
-=head3 --version
-
-Displays the version information.
+This is a flag for the vector measures. The definitions 
+used are 'cleaned'. If the --defraw flag is set they will not be 
+cleaned. 
 
 =head1 OUTPUT
 
@@ -230,7 +325,7 @@ use lib "/export/scratch/programs/lib/site_perl/5.8.7/";
 use UMLS::Interface;
 use Getopt::Long;
 
-eval(GetOptions( "version", "help", "username=s", "password=s", "hostname=s", "database=s", "socket=s", "measure=s", "config=s", "infile=s", "matrix", "dbfile=s", "precision=s", "info", "allsenses", "forcerun", "debug", "verbose", "propagationfile=s", "realtime", "stoplist=s", "debugfile=s", "matrixfile=s", "indexfile=s", "dictfile=s")) or die ("Please check the above mentioned option(s).\n");
+eval(GetOptions( "version", "help", "username=s", "password=s", "hostname=s", "database=s", "socket=s", "measure=s", "config=s", "infile=s", "matrix", "dbfile=s", "precision=s", "info", "allsenses", "forcerun", "debug", "verbose", "icfrequency", "icpropagation=s", "realtime", "stoplist=s", "debugfile=s", "vectormatrix=s", "vectorindex=s", "defraw", "dictfile=s", "t")) or die ("Please check the above mentioned option(s).\n");
 
 
 my $debug = 0;
@@ -527,20 +622,23 @@ sub loadMeasures {
 	my %vectoroptions = ();
 	
 	if(defined $opt_dictfile) {
-	    $vectoroptions{"dictsfile"} = $opt_dictfile;
+	    $vectoroptions{"dictfile"} = $opt_dictfile;
 	}
-	if(defined $opt_indexfile) {
-	    $vectoroptions{"indexfile"} = $opt_indexfile;
+	if(defined $opt_vectorindex) {
+	    $vectoroptions{"vectorindex"} = $opt_vectorindex;
 	}
 	if(defined $opt_debugfile) {
 	    $vectoroptions{"debugfile"} = $opt_debugfile;
 	}
-	if(defined $opt_matrixfile) {
-	    $vectoroptions{"matrixfile"} = $opt_matrixfile;
+	if(defined $opt_vectormatrix) {
+	    $vectoroptions{"vectormatrix"} = $opt_vectormatrix;
 	}
 	if(defined $opt_config) {
 	    $vectoroptions{"config"} = $opt_config;
 	}
+	if(defined $opt_defraw) { 
+	    $vectoroptions{"defraw"} = $opt_defraw;
+	}
 	$meas = UMLS::Similarity::vector->new($umls,\%vectoroptions);
     }
     #  load the module implementing the Leacock and 
@@ -595,25 +693,27 @@ sub loadMeasures {
 	$meas = UMLS::Similarity::random->new($umls);
     }
     
-    #  load the module implementing the lesk measure
-    if($measure eq "lesk") {
-    use UMLS::Similarity::lesk;
-	my %leskoptions = ();
-	
-	if(defined $opt_stoplist) {
-	    $leskoptions{"stoplist"} = $opt_stoplist;
-	}
-	if(defined $opt_debugfile) {
-	    $leskoptions{"debugfile"} = $opt_debugfile;
-	}
-	
-        $meas = UMLS::Similarity::lesk->new($umls,\%leskoptions);  
-    }
+#    #  load the module implementing the lesk measure
+#    if($measure eq "lesk") {
+#    use UMLS::Similarity::lesk;
+#	my %leskoptions = ();
+#	
+#	if(defined $opt_stoplist) {
+#	    $leskoptions{"stoplist"} = $opt_stoplist;
+#	}
+#	if(defined $opt_debugfile) {
+#	    $leskoptions{"debugfile"} = $opt_debugfile;
+#	}
+#	
+#	if(defined $opt_defraw) { 
+#	    $leskoptions{"defraw"} = $opt_defraw;
+#	}
+#        $meas = UMLS::Similarity::lesk->new($umls,\%leskoptions);  
+#    }
     
     die "Unable to create measure object.\n" if(!$meas);
     ($errCode, $errString) = $meas->getError();
     die "$errString\n" if($errCode);
-    $meas->{'trace'} = 1;
     
     return $meas;
 }
@@ -621,6 +721,9 @@ sub loadMeasures {
 #  load the UMLS
 sub loadUMLS {
  
+    if(defined $opt_t) { 
+	$option_hash{"t"} = 1;
+    }
     if(defined $opt_config) {
 	$option_hash{"config"} = $opt_config;
     }
@@ -636,8 +739,11 @@ sub loadUMLS {
     if(defined $opt_verbose) {
 	$option_hash{"verbose"} = $opt_verbose;
     }
-    if(defined $opt_propagationfile) {
-	$option_hash{"propagation"} = $opt_propagationfile;
+    if(defined $opt_icpropagation) {
+	$option_hash{"propagation"} = $opt_icpropagation;
+    }
+    if(defined $opt_icfrequency) { 
+	$option_hash{"frequency"} = $opt_icfrequency;
     }
     if(defined $opt_username and defined $opt_password) {
 	$option_hash{"driver"}   = "mysql";
@@ -665,28 +771,35 @@ sub checkOptions {
 	exit;
     }
 
-    if($opt_measure=~/\b(path|wup|lch|cdist|nam|vector|res|lin|random|jcn|lesk)\b/) {
-	#  good to go
+    if(defined $opt_measure) {
+	if($opt_measure=~/\b(path|wup|lch|cdist|nam|vector|res|lin|random|jcn)\b/) {
+	    #  good to go
+	}
+	else {
+	    print STDERR "The measure ($opt_measure) is not defined for\n";
+	    print STDERR "the UMLS-Similarity package at this time.\n\n";
+	    &minimalUsageNotes();
+	    exit;
+	}   
     }
-    else {
-	print STDERR "The measure ($opt_measure) is not defined for\n";
-	print STDERR "the UMLS-Similarity package at this time.\n\n";
-	&minimalUsageNotes();
-	exit;
-    }   
 	
     # make certain the db file is specified if the vector measure 
     # is being used
     if($opt_measure=~/vector/) {
-	if(! (defined $opt_indexfile)) {
-	    print STDERR "The --indexfile and --matrixfile option must be\n";
-	    print STDERR "specified when using the vector measure.\n\n";
+	if(! (defined $opt_vectorindex)) {
+	    print STDERR "The --vectorindex and --vectormatrix option must be\n";
+	    print STDERR "specified when using the vector measure. An example\n";
+	    print STDERR "of the matrix and index files can be seen in the \n";
+	    print STDERR "samples/ directory.\n\n";
 	    &minimalUsageNotes();
 	    exit;
 	}
-	if(! (defined $opt_matrixfile)) {
-	    print STDERR "The --indexfile and --matrixfile option must be\n";
-	    print STDERR "specified when using the vector measure.\n\n";
+	if(! (defined $opt_vectormatrix)) {
+	    print STDERR "The --vectorindex and --vectormatrix option must be\n";
+	    print STDERR "specified when using the vector measure.An example\n";
+	    print STDERR "of the index and matrix files can be seen in the\n";
+	    print STDERR "samples/ directory. The vector-input.pl program can\n";
+	    print STDERR "generate these files given your specific text. \n\n";
 	    &minimalUsageNotes();
 	    exit;
 	}
@@ -702,7 +815,7 @@ sub checkOptions {
     }    
 
     if(defined $opt_debugfile) { 
-	if(! ($opt_measure=~/(vector|lesk)/) ) {
+	if(! ($opt_measure=~/(vector)/) ) {
 	    print STDERR "The --debugfile option is only available\n";
 	    print STDERR "when using the vector measure.\n\n";
 	    &minimalUsageNotes();
@@ -710,27 +823,27 @@ sub checkOptions {
 	}
     }    
    
-    if(defined $opt_matrixfile and defined $opt_indexfile) { 
+    if(defined $opt_vectormatrix and defined $opt_vectorindex) { 
 	if(! ($opt_measure=~/vector/) ) {
-	    print STDERR "The --matrixfile and --indexfile options are only\n";
+	    print STDERR "The --vectormatrix and --vectorindex options are only\n";
 	    print STDERR "available when using the vector measure.\n\n";
 	    &minimalUsageNotes();
 	    exit;
 	}
     }    
     
-    if(defined $opt_matrixfile) { 
+    if(defined $opt_vectormatrix) { 
 	if(! ($opt_measure=~/vector/) ) {
-	    print STDERR "The --matrixfile option is only available\n";
-	    print STDERR "when using the vector measure.\n\n";
+	    print STDERR "The --vectormatrix option is only available\n";
+	    print STDERR "when using the vector measure. \n\n";
 	    &minimalUsageNotes();
 	    exit;
 	}
     }    
 
-    if(defined $opt_indexfile) { 
+    if(defined $opt_vectorindex) { 
 	if(! ($opt_measure=~/vector/) ) {
-	    print STDERR "The --indexfile option is only available\n";
+	    print STDERR "The --vectorindex option is only available\n";
 	    print STDERR "when using the vector measure.\n\n";
 	    &minimalUsageNotes();
 	    exit;
@@ -742,14 +855,34 @@ sub checkOptions {
     #  make certain the propagation file is specified if the resnik, 
     #  jcn, or lin measure is being used
     if($opt_measure=~/(res|lin|jcn)/) {
-	if(! (defined $opt_propagationfile)) {
-	    print STDERR "The --propagationfile option must be specified \n";
-	    print STDERR "when using the resnik or lin measures.\n\n";
+	if(! (defined $opt_icpropagation) and !(defined $opt_icfrequency) ) {
+	    print STDERR "The --icpropagation or --icfrequency option must be\n";
+	    print STDERR "specified when using the res, lin or jcn measures.\n";
+	    print STDERR "An example of the propagation file can be seen in\n";
+	    print STDERR "the samples/ directory.\n\n";
 	    &minimalUsageNotes();
 	    exit;
 	}
     } 
 
+    if(defined $opt_icpropagation || defined $opt_icfrequency) { 
+	if( !($opt_measure=~/(res|lin|jcn)/) ) {
+	    print STDERR "The --icpropagation or --icfrequency options\n";
+            print STDERR "may only be specified when using the res, lin\n";
+	    print STDERR "or jcn measures.\n\n";
+	    &minimalUsageNotes();
+	    exit;
+	}
+    }    
+
+
+    if(defined $opt_icpropagation and defined $opt_icfrequency) { 
+	print STDERR "You can specify both the --icpropagation and\n";
+	print STDERR "--icfrequency options at the same time.\n\n";
+	&minimalUsageNotes();
+	exit;
+    }    
+    
     if(defined $opt_precision) {
 	if ($opt_precision !~ /^\d+$/) {
 	    print STDERR "Value for switch --precision should be integer >= 0\n";
@@ -767,25 +900,33 @@ sub setOptions {
     my $default = "";
     my $set     = "";
 
-    if(defined $opt_propagationfile) {
-	$set .= "  --propagationfile $opt_propagationfile\n";
+    if(defined $opt_icpropagation) {
+	$set .= "  --icpropagation $opt_icpropagation\n";
+    }
+
+    if(defined $opt_icfrequency) {
+	$set .= "  --icfrequency $opt_icfrequency\n";
     }
 
     if(defined $opt_debugfile) { 
 	$set .= "  --debugfile $opt_debugfile\n";
     }
-    if(defined $opt_matrixfile) { 
-	$set .= "  --matrixfile $opt_matrixfile\n";
+    if(defined $opt_vectormatrix) { 
+	$set .= "  --vectormatrix $opt_vectormatrix\n";
     }
     
-    if(defined $opt_indexfile) { 
-	$set .= "  --indexfile $opt_indexfile\n";
+    if(defined $opt_vectorindex) { 
+	$set .= "  --vectorindex $opt_vectorindex\n";
     }
     
     if(defined $opt_dictfile) {
 	$set .= "  --dictfile $opt_dictfile\n";
     }
     
+    if(defined $opt_defraw) { 
+	$set .= "  --defraw\n";
+    }
+
     #  check config file
     if(defined $opt_config) {
 	$config = $opt_config;
@@ -927,7 +1068,55 @@ sub showHelp() {
   
     print "Usage: umls-similarity.pl [OPTIONS] TERM1 TERM2\n\n";
 
-    print "Options:\n\n";
+    print "General Options:\n\n";
+
+    print "--config FILE            Configuration file\n\n";
+        
+    
+    print "--realtime               This option finds the path and propagation\n";
+    print "                         information for relevant measures in realtime\n";
+    print "                         rather than building an index\n\n";
+
+    print "--forcerun               This option will bypass any command \n";
+    print "                         prompts such as asking if you would \n";
+    print "                         like to continue with the index \n";
+    print "                         creation. \n\n";
+
+    print "--measure MEASURE        The measure to use to calculate the\n";
+    print "                         semantic similarity. (DEFAULT: path)\n\n";
+
+    print "--precision N            Displays values upto N places of decimal.\n\n";
+
+    print "--allsenses              This option prints out all the possible\n";
+    print "                         CUIs pairs and their semantic similarity\n"; 
+    print "                         score if one of the inputs is a term that\n"; 
+    print "                         maps to more than one CUI. Right now we \n"; 
+    print "                         return the CUIs that are the most similar.\n\n";
+
+    print "--version                Prints the version number\n\n";
+    
+    print "--help                   Prints this help message.\n\n";
+
+    print "\n\nInput Options: \n\n";
+
+    print "--infile FILE            File containing TERM or CUI pairs\n\n";    
+
+    print "--matrix                 This option returns a matrix of similarity\n";
+    print "                         scores given a file containing a list of \n";
+    print "                         CUIs. File is specified using --infile.\n\n";
+    
+    print "\n\nDebug Options:\n\n";
+
+    print "--debug                  Sets the UMLS-Interface debug flag on\n";
+    print "                         for testing purposes\n\n";
+
+    print "--verbose                This option prints out the path information\n";
+    print "                         to a file in your config directory.\n\n";    
+
+    print "--info                   Displays information about a concept if\n";
+    print "                         it doesn't exist in the source.\n\n";
+    
+    print "\n\nDatabase Options: \n\n";
 
     print "--username STRING        Username required to access mysql\n\n";
 
@@ -936,57 +1125,42 @@ sub showHelp() {
     print "--hostname STRING        Hostname for mysql (DEFAULT: localhost)\n\n";
 
     print "--database STRING        Database contain UMLS (DEFAULT: umls)\n\n";
-        
-    print "--infile FILE            File containing TERM or CUI pairs\n\n";
+    
+    print "\n\nIC Measure Options:\n\n";
 
-    print "--propagationfile FILE   FILE containing the propagation counts\n";
+    print "--icpropagation FILE     File containing the information content\n";
+    print "                         of the CUIs.\n\n";
+
+    print "--icfrequency FILE       File containing the frequency counts\n";
     print "                         of the CUIs.\n\n";
     
-    print "--matrix                 This option returns a matrix of similarity\n";
-    print "                         scores given a file containing a list of \n";
-    print "                         CUIs. File is specified using --infile.\n\n";
+    print "\n\nVector Measure Options:\n\n";
 
-    print "--measure MEASURE        The measure to use to calculate the\n";
-    print "                         semantic similarity. (DEFAULT: path)\n\n";
-
-    print "--precision N            Displays values upto N places of decimal.\n\n";
-
-    print "--info                   Displays information about a concept if\n";
-    print "                         it doesn't exist in the source.\n\n";
-
-    print "--matrixfile FILE        The matrix file containing the vector\n";
+    print "--vectormatrix FILE        The matrix file containing the vector\n";
     print "                         information for the vector measure.\n\n";
 
-    print "--indexfile FILE         The index file containing the vector\n";
+    print "--vectorindex FILE         The index file containing the vector\n";
     print "                         information for the vector measure.\n\n";
 
-    print "--allsenses              This option prints out all the possible\n";
-    print "                         CUIs pairs and their semantic similarity\n"; 
-    print "                         score if one of the inputs is a term that\n"; 
-    print "                         maps to more than one CUI. Right now we \n"; 
-    print "                         return the CUIs that are the most similar.\n\n";
+    print "--debugfile FILE         This prints the vector information to file,\n";
+    print "                         FILE, for debugging purposes.\n\n";
 
-    print "--forcerun               This option will bypass any command \n";
-    print "                         prompts such as asking if you would \n";
-    print "                         like to continue with the index \n";
-    print "                         creation. \n\n";
-    
-    print "--debug                  Sets the UMLS-Interface debug flag on\n";
-    print "                         for testing purposes\n\n";
+    print "--dictfile FILE          This is a dictionary file for the vector measure.\n";
+    print "                         It contains the 'definitions' of a concept which\n";
+    print "                         would be used rather than the definitions from the\n";
+    print "                         UMLS\n\n";
+
+    print "--defraw                 This is a flag for the vector measure. The \n";
+    print "                         definitions used are 'cleaned'. If the --defraw flag \n";
+    print "                         is set they will not be cleaned. \n\n";
 
-    print "--verbose                This option prints out the path information\n";
-    print "                         to a file in your config directory.\n\n";    
-    
-    print "--version                Prints the version number\n\n";
-    
-    print "--help                   Prints this help message.\n\n";
 }
 
 ##############################################################################
 #  function to output the version number
 ##############################################################################
 sub showVersion {
-    print '$Id: umls-similarity.pl,v 1.23 2010/04/02 15:31:59 btmcinnes Exp $';
+    print '$Id: umls-similarity.pl,v 1.31 2010/04/15 17:08:48 btmcinnes Exp $';
     print "\nCopyright (c) 2008, Ted Pedersen & Bridget McInnes\n";
 }
 
